@@ -2,7 +2,7 @@ package Experian::IDAuth;
 use strict;
 use warnings;
 
-our $VERSION = '2.5';
+our $VERSION = '2.51';
 
 use Locale::Country;
 use Path::Tiny;
@@ -352,7 +352,7 @@ sub _get_result_proveid {
         || 0;
     $decision->{num_verifications} = $cr_total;
 
-    if ($kyc_dob and $cr_total) {
+    if ($kyc_dob or $cr_total) {
         $decision->{age_verified} = 1;
     }
 
@@ -514,10 +514,6 @@ sub _pdf_report_filename {
 
 Experian::IDAuth - Experian's ID Authenticate service
 
-=head1 VERSION
-
-Version 2.1
-
 =head1 DESCRIPTION
 
 This module provides an interface to Experian's Identity Authenticate service.
